Lotus International Character Set - Wikipedia

# Lotus International Character Set

From Wikipedia, the free encyclopedia
Jump to navigation Jump to search

The Lotus International Character Set (LICS) is a proprietary single-byte character encoding introduced in 1985 by Lotus Development Corporation. It is based on the 1983 DEC Multinational Character Set (MCS) for VT220 terminals. As such, LICS is also similar to two other descendants of MCS, the ECMA-94 character set of 1985[1] and the ISO 8859-1 (Latin-1) character set of 1987.

LICS was first introduced as the character set of Lotus 1-2-3 Release 2 for DOS in 1985.[2][3][4][5] It is also utilized by 2.01,[3][4][5] 2.2,[6][7][5] 2.3 and 2.4[8][9][10][11] as well as by Symphony. It was also utilized in a number of third-party spreadsheet products emulating the file format. LICS was superseded by the Lotus Multi-Byte Character Set (LMBCS) introduced by Lotus 1-2-3 Release 3 in 1989.[11]

## Character set[edit]

Codepoints 20hex (32) to 7Fhex (127) are identical to ASCII (as well as to LMBCS).[11] For some characters the table also lists dedicated Lotus 1-2-3 compose key sequences to ease character input beyond the Alt Numpad input method.

Lotus International Character Set[12][13]
| _0 | _1 | _2 | _3 | _4 | _5 | _6 | _7 | _8 | _9 | _A | _B | _C | _D | _E | _F
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
0_ | NUL 0000 | SOH 0001 | STX 0002 | ETX 0003 | EOT 0004 | ENQ 0005 | ACK 0006 | BEL 0007 | BS 0008 | HT 0009 | LF 000A | VT 000B | FF 000C | CR 000D | SO 000E | SI 000F
1_ | DLE 0010 | DC1 0011 | DC2 0012 | DC3 0013 | DC4 0014 | NAK 0015 | SYN 0016 | ETB 0017 | CAN 0018 | EM 0019 | SUB 001A | ESC 001B | FS 001C | GS 001D | RS 001E | US 001F
2_ | SP 0020 | ! 0021 | " 0022 | # 0023 ++ | $ 0024 | % 0025 | & 0026 | ' 0027 | ( 0028 | ) 0029 | * 002A | + 002B | , 002C | - 002D | . 002E | / 002F
3_ | 0 0030 | 1 0031 | 2 0032 | 3 0033 | 4 0034 | 5 0035 | 6 0036 | 7 0037 | 8 0038 | 9 0039 | : 003A | ; 003B | < 003C | = 003D | > 003E | ? 003F
4_ | @ 0040 aa | A 0041 | B 0042 | C 0043 | D 0044 | E 0045 | F 0046 | G 0047 | H 0048 | I 0049 | J 004A | K 004B | L 004C | M 004D | N 004E | O 004F
5_ | P 0050 | Q 0051 | R 0052 | S 0053 | T 0054 | U 0055 | V 0056 | W 0057 | X 0058 | Y 0059 | Z 005A | [ 005B (( | \ 005C // | ] 005D )) | ^ 005E vv | _ 005F
6_ | ` 0060 | a 0061 | b 0062 | c 0063 | d 0064 | e 0065 | f 0066 | g 0067 | h 0068 | i 0069 | j 006A | k 006B | l 006C | m 006D | n 006E | o 006F
7_ | p 0070 | q 0071 | r 0072 | s 0073 | t 0074 | u 0075 | v 0076 | w 0077 | x 0078 | y 0079 | z 007A | { 007B (- | | 007C ^/ | } 007D )- | ~ 007E -- | DEL/▒ 007F/2592
8_ | ̀ 0300 `SP | ́ 0301 'SP | ̂ 0302 ^SP | ̈ 0308 "SP | ̃ 0303 ~SP |  |  |  |  |  |  |  |  |  |  |
9_ | ̀ 0300 SP` | ́ 0301 SP' | ̂ 0302 SP^ | ̈ 0308 SP" | ̃ 0303 SP~ | ı 0131 iSP | ̱ 0331 _SP | ▲ 25B2 ba | ▼ 25BC ea |  | NBSP 00A0 SP SP | ← 2190 mg |  |  |  |
A_ | ƒ 0192 ff | ¡ 00A1 !! | ¢ 00A2 c/ | £ 00A3 l- | “ 201C "^ | ¥ 00A5 y- | ₧ 20A7 pt | § 00A7 so | ¤ 00A4 xo | © 00A9 co | ª 00AA a_ | « 00AB << | Δ 0394 dd | π 03C0 pi | ≥ 2265 >= | ÷ 00F7 :-
B_ | ° 00B0 ^0 | ± 00B1 +- | ² 00B2 ^2 | ³ 00B3 ^3 | „ 201E "v | µ/μ 00B5/03BC /u | ¶ 00B6 !p | · 00B7 ^. | ™ 2122 tm | ¹ 00B9 ^1 | º 00BA o_ | » 00BB >> | ¼ 00BC | ½ 00BD | ≤ 2264 =< | ¿ 00BF ??
C_ | À 00C0 A` | Á 00C1 A' | Â 00C2 A^ | Ã 00C3 A~ | Ä 00C4 A" | Å 00C5 A* | Æ 00C6 AE | Ç 00C7 C, | È 00C8 E` | É 00C9 E' | Ê 00CA E^ | Ë 00CB E" | Ì 00CC I` | Í 00CD I' | Î 00CE I^ | Ï 00CF I"
D_ | Ð 00D0 D- | Ñ 00D1 N~ | Ò 00D2 O` | Ó 00D3 O' | Ô 00D4 O^ | Õ 00D5 O~ | Ö 00D6 O" | Œ 0152 OE | Ø 00D8 O/ | Ù 00D9 U` | Ú 00DA U' | Û 00DB U^ | Ü 00DC U" | Ÿ 0178 Y" | Þ 00DE P- | ß 00DF ss
E_ | à 00E0 a` | á 00E1 a' | â 00E2 a^ | ã 00E3 a~ | ä 00E4 a" | å 00E5 a* | æ 00E6 ae | ç 00E7 c, | è 00E8 e` | é 00E9 e' | ê 00EA e^ | ë 00EB e" | ì 00EC i` | í 00ED i' | î 00EE i^ | ï 00EF i"
F_ | ð 00F0 d- | ñ 00F1 n~ | ò 00F2 o` | ó 00F3 o' | ô 00F4 o^ | õ 00F5 o~ | ö 00F6 o" | œ 0153 oe | ø 00F8 o/ | ù 00F9 u` | ú 00FA u' | û 00FB u^ | ü 00FC u" | ÿ 00FF y" | þ 00FE p- |

Letter Number Punctuation Symbol Other Undefined Differences from ISO-8859-1

## See also[edit]

- Lotus Multi-Byte Character Set (LMBCS)
- DEC Multinational Character Set (MCS)
- BraSCII

## References[edit]

1. ^
   Standard ECMA-94: 8-bit Single-Byte Coded Graphic Character Set (PDF) (1 ed.). European Computer Manufacturers Association (ECMA). March 1985 [1984-12-14]. Archived (PDF) from the original on 2016-12-02. Retrieved 2016-12-01. […] Since 1982 the urgency of the need for an 8-bit single-byte coded character set was recognized in ECMA as well as in ANSI/X3L2 and numerous working papers were exchanged between the two groups. In February 1984 ECMA TC1 submitted to ISO/TC97/SC2 a proposal for such a coded character set. At its meeting of April 1984 SC decided to submit to TC97 a proposal for a new item of work for this topic. Technical discussions during and after this meeting led TC1 to adopt the coding scheme proposed by X3L2. Part 1 of Draft International Standard DTS 8859 is based on this joint ANSI/ECMA proposal. […] Adopted as an ECMA Standard by the General Assembly of Dec. 13–14, 1984. […]
2. ^ Schemenaur, P. J. (1986-10-27). "Firm to Debut Clone Version of Lotus 1-2-3 - Program Offers 2.0 Compatibility". InfoWorld. Retrieved 2016-11-29. […] Twin Release 2 keeps the IBM extended character set of Version 1A, rather than Release 2.0's Lotus International Character Set, which […] causes problems with commercial templates designed for Lotus 1-2-3, Release 1A. […]
3. ^ a b Attia, Zayn 'Utbah (2015-03-11). "ASCII graphic characters, range names". Computer Tips. Archived from the original on 2016-11-30. Retrieved 2016-11-29. […] Release 1A's capability to use extended graphics characters to dress up a screen was an undocumented feature. These characters allowed you to draw boxes and add special symbols on the screen. With Release 2, Lotus has assigned different meanings to these characters, the Lotus International Character Set, LICS. Any these extended characters must be erased or replaced with regular keyboard characters before the character can appear acceptable on an Release 2 screen. Release 2.01 offers an install option to use extended characters rather than LICS characters. […]
4. ^ a b Cobb, Douglas; Cobb, Steven (1988-10-31). "Spreadsheet clinic: How to adjust SuperCalc's financial functions to analyze annuities due, create flashing screen messages in 1-2-3, and access upper-level ASCII characters in Quattro and 1-2-3". PC Magazine: 411. Archived from the original on 2016-12-02. Retrieved 2016-12-01. […] Unlike 1-2-3, Quattro uses the ASCII character set. By default, 1-2-3, Release 2.01, uses the Lotus International Character Set (LICS) — the same character set that Release 2.0 always uses […] you can command Release 2.01 to use the ASCII character set, just as Quattro does. […] load the install program, and select Advanced Options […] select TextDisplay […] choose Universal Text Display — ASCII-No LICS […] Now, when you load 1-2-3 using the modified driver set, the @CHAR function will produce upper-level ASCII characters […] (NB. By "Upper-level ASCII", the authors actually meant the 8-bit OEM character set.)
5. ^ a b c "Kapitel 4. Kompatibilität mit anderen 1-2-3 Versionen - Zeichensätze" [Chapter 4. Compatility with other 1-2-3 Versions - Character Sets]. Lotus 1-2-3 Version 3.1 Upgrader's Handbuch [Upgrader's handbook] (in German) (1 ed.). Cambridge, MA, USA: Lotus Development Corporation. 1989. pp. 4-10–4-11. 302173.
6. ^ "HP 95LX". InfoWorld: 72. 1991-12-16. Retrieved 2016-11-26.
7. ^ Matzkin, Jonathan (July 1991). "Hewlett-Packard Co. HP 95LX Palmtop PC". PC Magazine: 216, 220, 222. Retrieved 2016-11-26.
8. ^ Lee, Yvonne (1993-05-03). "HP 100LX rolled out as successor to palmtop". InfoWorld: 27. Retrieved 2016-11-26.
9. ^ Marshall, Patrick (1993-08-23). "Hewlett-Packard makes a good thing better by packing 100LX with features". InfoWorld. Retrieved 2016-11-26.
10. ^ "Questions and Answers about HP Palmtops: Q. What software is built into the 200LX ROM?". The HP Palmtop Paper Online. Archived from the original on 2016-11-27. Retrieved 2016-11-26.
11. ^ a b c Kamenz, Alfred; Vonhoegen, Helmut (1992). Das große Buch zu Lotus 1-2-3 für DOS (in German) (1 ed.). Data Becker. pp. 131–132, 357–358. ISBN 3-89011-375-3.
12. ^ "Appendix F: Lotus International Character Set (LICS)" (PDF). HP 95LX User's Guide (2 ed.). Corvallis, OR, USA: Hewlett-Packard Company, Corvallis Division. June 1991 [March 1991]. pp. 792–799. Archived (PDF) from the original on 2016-11-28. Retrieved 2016-11-27.
13. ^ "Anhang 2. Der Lotus Multibyte Zeichensatz (LMBCS)" [Appendix 2. The Lotus Multibyte Character Set (LMBCS)]. Lotus 1-2-3 Version 3.1 Referenzhandbuch [Lotus 1-2-3 Version 3.1 Reference Manual] (in German) (1 ed.). Cambridge, MA, USA: Lotus Development Corporation. 1989. pp. A2-1–A2-13. 302168. (While for Lotus 1-2-3 Release 3.1+ for DOS, the manual also contains a few notes on LICS.)

## Further reading[edit]

- Born, Günter (December 2000) [1990]. "Kapitel 1. LOTUS 1-2-3-Format (WKS/WK1)" [Chapter 1. Lotus 1-2-3 WKS/WK1 format]. Dateiformate - Eine Referenz - Tabellenkalkulation, Text, Grafik, Multimedia, Sound und Internet [File formats - a reference - spreadsheets, text, graphics, multimedia, sound and internet] (PDF) (in German). Bonn, Germany: Galileo Computing. ISBN 3-934358-83-7. Archived (PDF) from the original on 2016-11-29. Retrieved 2016-11-28. (May help retrieving info on LICS.)
- HP 200LX User's Guide (PDF) (1 ed.). Singapore: Hewlett-Packard Singapore (Private) Limited, Asia-Pacific Personal Computer Division. October 1996. pp. 21-6–21-7, 25-9–25-13, 26-14–26-18, C-1–C-4, D-1–D-10. 1216-90001. Archived (PDF) from the original on 2016-11-30. Retrieved 2016-11-29. Your palmtop supports code pages 850 and 437. […] 1-2-3 uses LICS, the Lotus International Character Set. Most LICS characters are included in code page 850; the few that are not included will not display on the palmtop.
- "LMBCS tables". User's Guide - 123 Release 4 for Windows (Fax). Lotus Development. 1995 [1994-01-01]. CHAPTER: Appendix A Using the Lotus Multibyte Character Set. Fax 10955. Retrieved 2016-12-06.
- Lotus Development Corporation (December 1984). "Worksheet File Format from Lotus - Introduction and Quick Reference". File Format Documentation Collection. Cambridge, Massachusetts, USA. Archived from the original on 2016-11-30. Retrieved 2016-12-12.
- Lotus Development Corporation (December 1984). "Worksheet File Format from Lotus - Summary of Record Types". File Format Documentation Collection. Cambridge, Massachusetts, USA. Archived from the original on 2016-12-01. Retrieved 2016-12-12.
- Lotus Development Corporation (December 1984). "Worksheet File Format from Lotus - Appendix A - Cell Format Encoding". File Format Documentation Collection. Cambridge, Massachusetts, USA. Archived from the original on 2016-12-01. Retrieved 2016-12-12.
- Lotus Development Corporation (December 1984). "Worksheet File Format from Lotus - Appendix B - The Formula Compiler". File Format Documentation Collection. Cambridge, Massachusetts, USA. Archived from the original on 2016-12-01. Retrieved 2016-12-12.
- Lotus Development Corporation (1985-02-19). "Addendum to Worksheet File Format Document". File Format Documentation Collection. Cambridge, Massachusetts, USA. Archived from the original on 2016-12-01. Retrieved 2016-12-12.
- Lotus 1-2-3 Release 2.x User Guide Appendix A. (NB. Reportedly contains info on LICS.)
- The file `LICS.EAT` ("Extended ASCII Table") in Lotus 1-2-3 Release 2.x for DOS reportedly contains detailed info on LICS.
- The Lotus Symphony 1.2 and Notes 2.1 Character Translation File (CTF) `LICS850.CTF` and the Notes 3.0 Country Language Services (CLS) file `L_LICS.CLS` contain LICS character translation information.
- "Bug 87222 - Summary: Works spreadsheet: wrong encoding". LibreOffice. 2014-12-11. Retrieved 2016-12-12. (NB. Temporarily left here for quick reference, but contains somewhat confused info.)
- https://sourceforge.net/p/libwps/code/ci/master/tree/src/lib/libwps_tools_win.cpp (Contains a LICS to Unicode conversion routine, which, however, is buggy)

Retrieved from "https://en.wikipedia.org/w/index.php?title=Lotus_International_Character_Set&oldid=1048902759"
Categories:

- Computer-related introductions in 1985
- Character encoding
- Character sets
- Lotus Software software

Hidden categories:

- CS1 German-language sources (de)